@@ -122,6 +122,11 @@ public class HtmlConfiguration extends BaseConfiguration {
      */
     public String helpfile = "";
 
+    /**
+     * Argument for command-line option "--legal-notices".
+     */
+    public String legalnotices = "";
+
     /**
      * Argument for command line option "-stylesheetfile".
      */
@@ -656,6 +661,13 @@ public class HtmlConfiguration extends BaseConfiguration {
                     return true;
                 }
             },
+            new XOption(resources, "--legal-notices", 1) {
+                @Override
+                public boolean process(String opt,  List<String> args) {
+                    legalnotices = args.get(0);
+                    return true;
+                }
+            },
             new Option(resources, "-nohelp") {
                 @Override
                 public boolean process(String opt, List<String> args) {
