@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -1267,6 +1267,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "timezone.excity.America/Thule", "Q\u00e2n\u00e2q" },
             { "timezone.excity.Asia/Riyadh", "Riyadh" },
             { "America/Yakutat", Alaska },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "Europe/Copenhagen", Europe_Central },
             { "timezone.excity.Africa/Bangui", "Bangui" },
             { "timezone.excity.Africa/Lusaka", "Lusaka" },
@@ -1365,7 +1366,6 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "SystemV/YST9", Gambier },
             { "timezone.excity.Pacific/Nauru", "Nauru" },
             { "Africa/Douala", Africa_Western },
-            { "America/Ojinaga", America_Mountain },
             { "timezone.excity.Europe/Lisbon", "Lisboa" },
             { "timezone.excity.Pacific/Pago_Pago", "Pago Pago" },
             { "timezone.excity.Pacific/Gambier", "Gambier" },
