@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -1474,6 +1474,7 @@ public class TimeZoneNames_lt extends TimeZoneNamesBundle {
             { "timezone.excity.America/Thule", "Kanakas" },
             { "timezone.excity.America/Grand_Turk", "Grand Terkas" },
             { "America/Yakutat", Alaska },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "timezone.excity.America/Indiana/Petersburg", "Pitersbergas, Indiana" },
             { "Europe/Vienna", Europe_Central },
             { "timezone.excity.America/Winnipeg", "Vinipegas" },
@@ -1981,8 +1982,8 @@ public class TimeZoneNames_lt extends TimeZoneNamesBundle {
             { "timezone.excity.Pacific/Kwajalein", "Kvad\u017ealeinas" },
             { "SystemV/YST9", Gambier },
             { "Africa/Douala", Africa_Western },
-            { "America/Chihuahua", Mexico_Pacific },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Chihuahua", America_Central },
+            { "America/Ojinaga", America_Central },
             { "Asia/Hovd", Hovd },
             { "timezone.excity.Europe/Lisbon", "Lisabona" },
             { "timezone.excity.Pacific/Gambier", "Gambyras" },
